@@ -31,13 +31,6 @@ testing.add('kali-themes')
 testing.add('kali-themes-common')
 testing.add('kali-undercover')
 
-# Add Ubuntu
-testing.add('ubuntu-advantage-tools')
-testing.add('ubuntu-drivers-common')
-testing.add('ubuntu-fan')
-testing.add('ubuntu-mono')
-testing.add('ubuntu-release-upgrader-core')
-
 # Google repository
 testing.add('google-earth-stable')
 
@@ -46,6 +39,11 @@ if old_stable != STABLE:
     print('Stable distribution has changed: %s -> %s' % (old_stable, STABLE))
     os.unlink('archive/stable')
     os.chdir('archive')
+    if not os.path.isdir(STABLE):
+        os.mkdir(STABLE)
+        gitkeep = os.path.join(STABLE, '.gitkeep')
+        open(gitkeep, 'w').close()
+        subprocess.call(['git', 'add', gitkeep])
     os.symlink(STABLE, 'stable')
     os.chdir('..')
 
@@ -77,6 +75,9 @@ def process(category, packages, testing, stable, archive):
         if not os.path.isdir(destdir):
             os.makedirs(destdir)
         subprocess.call(['git', 'mv', os.path.join(category, item), destdir])
+        gitkeep = os.path.join(destdir, '.gitkeep')
+        if os.path.isfile(gitkeep):
+            subprocess.call(['git', 'rm', gitkeep])
     print('unknown:', sorted(unknown))
 
 process('rules', filters, testing, stable, STABLE)
